==> enterprisemodules-pg_config-0.4.2.tar.gz: enterprisemodules-pg_config-0.4.2/lib/puppet/type/pg_role.rb <==
# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#

require 'pathname'
$LOAD_PATH.unshift(Pathname.new(__FILE__).dirname.parent.parent)
$LOAD_PATH.unshift("#{Pathname.new(__FILE__).dirname.parent.parent.parent.parent}easy_typelib")
require 'easy_type'
require 'easy_type/array_property'
require 'puppet_x/enterprisemodules/postgres/access'
require 'puppet_x/enterprisemodules/postgres/read_only_property'
require 'puppet_x/enterprisemodules/postgres/password'
require 'puppet_x/enterprisemodules/postgres/create_only'
require 'puppet_x/enterprisemodules/postgres/title_parser'
require 'puppet_x/enterprisemodules/postgres/utilities'

#
# Create a new type pg_role
#
Puppet::Type.newtype(:pg_role) do
  include EasyType
  include Puppet_X::EnterpriseModules::Postgres::Access
  include Puppet_X::EnterpriseModules::Postgres::Utilities
  extend Puppet_X::EnterpriseModules::Postgres::TitleParser

  desc <<-DOC
  This type allows you to manage a role/user in a Postgres database. Here is an example:

      pg_role { role_name@db:
        password  => 'verysecret',
        login     => true,
        create_db => true,
      }

  The `pg_role` type recognises all of the options you also have when using SQL to create a user or a role.
  DOC

  ensurable

  to_get_raw_resources do
    sql_on_all_databases 'select * from pg_roles'
  end

  on_create do
    self[:password] ||= generated_password
    [:sql, "create role #{role_name}", { :db => db }]
  end

  on_modify do
    [:sql, "alter role #{role_name}", { :skip_without_properties => true, :db => db }]
  end

  on_destroy do
    [:sql, "drop role #{role_name}", { :db => db }]
  end

  map_title_to_db(:role_name)

  parameter :name
  parameter :role_name
  parameter :db
  parameter :create_only

  property :oid
  #
  # The rights the role has
  #
  property :super_user
  property :create_role
  property :inherit
  property :create_db
  property :login
  property :replication
  property :bypass
  property :max_connections
  property :valid_until
  property :password
end

==> enterprisemodules-pg_config-0.5.0.tar.gz: enterprisemodules-pg_config-0.5.0/lib/puppet/type/pg_role.rb <==
# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#

require 'pathname'
$LOAD_PATH.unshift(Pathname.new(__FILE__).dirname.parent.parent)
$LOAD_PATH.unshift("#{Pathname.new(__FILE__).dirname.parent.parent.parent.parent}easy_typelib")
require 'easy_type'
require 'easy_type/array_property'
require 'puppet_x/enterprisemodules/postgres/access'
require 'puppet_x/enterprisemodules/postgres/read_only_property'
require 'puppet_x/enterprisemodules/postgres/password'
require 'puppet_x/enterprisemodules/postgres/create_only'
require 'puppet_x/enterprisemodules/postgres/title_parser'
require 'puppet_x/enterprisemodules/postgres/utilities'

#
# Create a new type pg_role
#
Puppet::Type.newtype(:pg_role) do
  include EasyType
  include Puppet_X::EnterpriseModules::Postgres::Access
  include Puppet_X::EnterpriseModules::Postgres::Utilities
  extend Puppet_X::EnterpriseModules::Postgres::TitleParser

  desc <<-DOC
  This type allows you to manage a role/user in a Postgres database. Here is an example:

      pg_role { role_name@db:
        password  => 'verysecret',
        login     => true,
        create_db => true,
      }

  The `pg_role` type recognises all of the options you also have when using SQL to create a user or a role.
  DOC

  ensurable

  to_get_raw_resources do
    sql_on_cluster_databases 'select * from pg_roles'
  end

  on_create do
    self[:password] ||= generated_password
    [:sql, "create role #{role_name}", { :db => db }]
  end

  on_modify do
    [:sql, "alter role #{role_name}", { :skip_without_properties => true, :db => db }]
  end

  on_destroy do
    [:sql, "drop role #{role_name}", { :db => db }]
  end

  map_title_to_db(:role_name)

  parameter :name
  parameter :role_name
  parameter :db
  parameter :create_only

  property :oid
  #
  # The rights the role has
  #
  property :super_user
  property :create_role
  property :inherit
  property :create_db
  property :login
  property :replication
  property :bypass
  property :max_connections
  property :valid_until
  property :password
end
